import { Color, CoreTypes, Font } from '@nativescript/core';
import { TabContentItem } from '../tab-content-item';
import { TabStrip } from '../tab-strip';
import { TabStripItem } from '../tab-strip-item';
import { TabNavigationBase } from './index-common';
export * from './index-common';
export { TabContentItem, TabStrip, TabStripItem };
export declare const PRIMARY_COLOR = "colorPrimary";
export interface PositionChanger {
    onSelectedPositionChange(position: number, prevPosition: number): any;
}
export declare function getDefaultAccentColor(context: android.content.Context): number;
export declare const tabs: WeakRef<TabNavigation<any>>[];
export declare abstract class TabNavigation<T extends android.view.ViewGroup = any> extends TabNavigationBase {
    nativeViewProtected: org.nativescript.widgets.GridLayout;
    protected mTabsBar: T;
    protected mViewPager: androidx.viewpager2.widget.ViewPager2;
    protected mPageListener: androidx.viewpager2.widget.ViewPager2.OnPageChangeCallback;
    protected mPagerAdapter: androidx.viewpager2.adapter.FragmentStateAdapter;
    protected mAndroidViewId: number;
    _originalBackground: any;
    protected mTextTransform: CoreTypes.TextTransformType;
    protected mSelectedItemColor: Color;
    protected mUnSelectedItemColor: Color;
    fragments: androidx.fragment.app.Fragment[];
    protected tabBarLayoutParams: org.nativescript.widgets.CommonLayoutParams;
    constructor();
    get _hasFragments(): boolean;
    onItemsChanged(oldItems: TabContentItem[], newItems: TabContentItem[]): void;
    createNativeView(): org.nativescript.widgets.GridLayout;
    protected abstract createNativeTabBar(context: android.content.Context): T;
    protected abstract setTabBarItems(tabItems: com.nativescript.material.core.TabItemSpec[]): any;
    protected abstract getTabBarItemView(index: number): any;
    protected abstract getTabBarItemTextView(index: number): any;
    protected abstract selectTabBar(oldIndex: number, newIndex: number): any;
    private handleTabStripChanged;
    onTabStripChanged(oldTabStrip: TabStrip, newTabStrip: TabStrip): void;
    onSelectedIndexChanged(oldIndex: number, newIndex: number): void;
    initNativeView(): void;
    disposeNativeView(): void;
    onLoaded(): void;
    onUnloaded(): void;
    private shouldUpdateAdapter;
    private setItems;
    protected setTabStripItems(items: TabStripItem[]): void;
    protected createTabItemSpec(tabStripItem: TabStripItem): com.nativescript.material.core.TabItemSpec;
    private getOriginalIcon;
    private getDrawableInfo;
    private getIconInfo;
    private getFixedSizeIcon;
    protected abstract updateTabsBarItemAt(index: number, spec: com.nativescript.material.core.TabItemSpec): any;
    protected abstract setTabsBarSelectedIndicatorColors(colors: number[]): any;
    updateAndroidItemAt(index: number, spec: com.nativescript.material.core.TabItemSpec): void;
    getTabBarBackgroundColor(): android.graphics.drawable.Drawable;
    setTabBarBackgroundColor(value: android.graphics.drawable.Drawable | Color): void;
    getTabBarHighlightColor(): number;
    setTabBarHighlightColor(value: number | Color): void;
    getTabBarSelectedItemColor(): Color;
    setTabBarSelectedItemColor(value: Color): void;
    getTabBarUnSelectedItemColor(): Color;
    setTabBarUnSelectedItemColor(value: Color): void;
    private updateItem;
    setTabBarItemTitle(tabStripItem: TabStripItem, value: string): void;
    setTabBarItemBackgroundColor(tabStripItem: TabStripItem, value: android.graphics.drawable.Drawable | Color): void;
    _setItemColor(tabStripItem: TabStripItem): void;
    protected setIconColor(tabStripItem: TabStripItem, color?: Color): void;
    setTabBarItemColor(tabStripItem: TabStripItem, value: number | Color): void;
    setTabBarIconColor(tabStripItem: TabStripItem, value: number | Color): void;
    setTabBarIconSource(tabStripItem: TabStripItem, value: number | Color): void;
    setTabBarItemFontInternal(tabStripItem: TabStripItem, value: Font): void;
    setTabBarItemTextTransform(tabStripItem: TabStripItem, value: CoreTypes.TextTransformType): void;
    setTabBarTextTransform(value: CoreTypes.TextTransformType): void;
    onTabsBarSelectedPositionChange(position: number, prevPosition: number): void;
    onTabsBarTap(position: number): boolean;
}
