/**
 * @module @nativescript-community/ui-material-core-tabs/tab-navigation
 */
import { Color, CoreTypes, Font, Property } from '@nativescript/core';
import { TabContentItem } from '../tab-content-item';
import { TabStrip } from '../tab-strip';
import { TabStripItem } from '../tab-strip-item';
import { TabNavigationBase } from './index-common';
export { TabContentItem, TabStrip, TabStripItem };
export declare function updateBackgroundPositions(tabStrip: TabStrip, tabStripItem: TabStripItem, color?: UIColor): void;
export declare function updateTitleAndIconPositions(tabStripItem: TabStripItem, tabBarItem: UITabBarItem, controller: UIViewController): void;
export declare const iosCustomPositioningProperty: Property<TabNavigation<any>, boolean>;
export declare abstract class TabNavigation<T extends UIPageViewController & {
    tabBar: MDCTabBarView;
    scrollView: UIScrollView;
} = any> extends TabNavigationBase {
    nativeViewProtected: UIView;
    selectedIndex: number;
    mCanSelectItem: boolean;
    isLoaded: boolean;
    viewController: T;
    items: TabContentItem[];
    viewControllers: UIViewController[];
    tabBarItems: UITabBarItem[];
    private mCurrentNativeSelectedIndex;
    private mDataSource;
    private mDelegate;
    private mIconsCache;
    private mBackgroundIndicatorColor;
    mDefaultItemBackgroundColor: UIColor;
    private mSelectedItemColor;
    private mUnSelectedItemColor;
    animationEnabled: boolean;
    mNeedsCacheUpdate: boolean;
    mAnimateNextChange: boolean;
    private mSelectionIndicatorColor;
    private mRippleColor;
    iosCustomPositioning: boolean;
    private mLayoutPending;
    protected abstract createViewController(): T;
    constructor();
    createNativeView(): UIView;
    initNativeView(): void;
    disposeNativeView(): void;
    requestLayout(): void;
    beginTabTransition(): void;
    finishTabTransition(): void;
    onLoaded(): void;
    onUnloaded(): void;
    get ios(): T;
    layoutNativeView(left: number, top: number, right: number, bottom: number): void;
    _setNativeViewFrame(nativeView: UIView, frame: CGRect): void;
    onSelectedIndexChanged(oldIndex: number, newIndex: number): void;
    onMeasure(widthMeasureSpec: number, heightMeasureSpec: number): void;
    _onViewControllerShown(viewController: UIViewController): void;
    private getViewController;
    _setCanBeLoaded(index: number): void;
    private setViewControllers;
    onItemsChanged(oldItems: TabContentItem[], newItems: TabContentItem[]): void;
    private setItemImages;
    private updateAllItemsColors;
    private updateItemColors;
    private createTabBarItem;
    private getIconRenderingMode;
    private getIcon;
    private getFixedSizeIcon;
    getTabBarBackgroundColor(): UIColor;
    setTabBarBackgroundColor(value: UIColor | Color): void;
    setTabBarItemTitle(tabStripItem: TabStripItem, value: string): void;
    setTabBarItemTextTransform(tabStripItem: TabStripItem, value: CoreTypes.TextTransformType): void;
    setTabBarTextTransform(value: CoreTypes.TextTransformType): void;
    private equalUIColor;
    private isSelectedAndHightlightedItem;
    setTabBarItemBackgroundColor(tabStripItem: TabStripItem, value: UIColor | Color): void;
    setTabBarItemColor(tabStripItem: TabStripItem, value: UIColor | Color): void;
    private setItemColors;
    private setIconColor;
    setTabBarIconColor(tabStripItem: TabStripItem, value: UIColor | Color): void;
    setTabBarIconSource(tabStripItem: TabStripItem, value: UIColor | Color): void;
    setTabBarItemFontInternal(tabStripItem: TabStripItem, value: Font): void;
    getTabBarFontInternal(): UIFont;
    setTabBarFontInternal(): void;
    getTabBarColor(): UIColor;
    setTabBarColor(value: UIColor | Color): void;
    getTabBarHighlightColor(): Color;
    setTabBarHighlightColor(value: Color): void;
    getTabBarSelectedItemColor(): Color;
    setTabBarSelectedItemColor(value: Color): void;
    getTabBarUnSelectedItemColor(): Color;
    setTabBarUnSelectedItemColor(value: Color): void;
    private visitFrames;
    setTabBarRippleColor(value: Color, alpha?: number): void;
    getTabBarRippleColor(): Color;
    private setViewTextAttributes;
}
